Settings and help — ADA 1.0.3 documentation

Skip to main content
`Ctrl`+`K`

# Settings and help

## Themes

ADA supports light and dark themes. Switch between them via View → Dark / Light in the menu bar. The screenshot below shows the light theme:

## Data formats

ADA currently supports the following data formats:

1. GENEActiv Original (.bin and .csv)

2. Actigraph Corp. raw data (.gt3x)

3. MESA dataset (.csv)

One can also use the Export option under the File tab in order to save loaded files as .ada without any processing. It might be usefull if one plans to reuse data, as .ada offers much higher reading speed than native .bin or .gt3x formats.

## File selection dialogs

The View menu also contains the System file dialogs toggle. When checked (default on macOS and Windows), file and directory selection uses the operating system’s native dialogs. When unchecked (default on Linux), ADA uses its own built-in file browser.

## Help

In the Help pull-down section users can read details about methods used in ADA GUI.